@@ -130,6 +130,8 @@ def create_department(data: dict) -> dict:
     # 构造path
     parent_id = data.pop("parent_id")
     parent = Department.objects.get(pk=parent_id)
+    if parent.organization_id != data["organization_id"]:
+        raise ValueError(f"organization_id:{data['organization_id']} different of parent organization_id: {parent.organization_id}")
     if parent.path:
         path = parent.path
         path.append(parent.id)
@@ -321,7 +323,10 @@ def mv_show_order(organization_id: int, data: dict):
     :return:
     """
     for item in data:
-        Department.objects.filter(id=item["id"], organization_id=organization_id).update(show_order=item["show_order"])
+        obj = Department.objects.filter(id=item["id"], organization_id=organization_id)
+        if not obj:
+            raise ValueError(f"organization {organization_id} not found department {item['id']}")
+        obj.update(show_order=item["show_order"])
 
     return Resp()
 
