@@ -14,29 +14,28 @@ if __name__ == '__main__':
 
     from departments.views.department import create_department, DepartmentViewSet
 
-
-    def response(func):
-        def wrapper(*args, **kwargs):
-            res = func(*args, **kwargs)
-            print(json.loads(res.content))
-        return wrapper
-
-    # 创建部门
-    @response
-    def create_department_():
-        post_data = {
-            "name": "python",
-            "parent_id": 2,
-            "charger_id": None,
-            "organization_id": 1
-        }
-        res = create_department(post_data)
-        return res
+    # def response(func):
+    #     def wrapper(*args, **kwargs):
+    #         res = func(*args, **kwargs)
+    #         print(json.loads(res.content))
+    #     return wrapper
+    #
+    # # 创建部门
+    # @response
+    # def create_department_():
+    #     post_data = {
+    #         "name": "python",
+    #         "parent_id": 2,
+    #         "charger_id": None,
+    #         "organization_id": 1
+    #     }
+    #     res = create_department(post_data)
+    #     return res
 
 
-    obj = DepartmentViewSet(1)
+    # obj = DepartmentViewSet(1)
     # print(obj.list("sub", 2))
-    print(obj.list("all"))
+    # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端o99", "parent_id": 2}))
     # print(obj.retrieve(3))
@@ -46,7 +45,4 @@ if __name__ == '__main__':
     # print(obj.create_department_user(5, [1, 2, 3]))
     # print(obj.department_user_list(5,))
     # print(obj.delete_department_user(5, [11]))
-    # print(obj.get_chargers())
-
-
-
+    # print(obj.get_chargers())
\ No newline at end of file
